@@ -1,12 +1,14 @@
+from typing import List, Optional, Any, Annotated, Generic
+
 import pydantic_ai
 from pydantic import PlainValidator
 from pydantic_ai import RunContext, ModelRetry
 from pydantic_ai._output import OutputDataT
 from pydantic_ai.agent import AgentRunResult, Agent
 from pydantic_ai.models.openai import OpenAIModel
+from pydantic_ai.output import OutputSpec, NativeOutput, ToolOutput
 from pydantic_ai.providers.openai import OpenAIProvider
 from pydantic_ai.tools import AgentDepsT
-from typing import List, Optional, Any, Annotated, Generic
 
 from fmtr.tools import environment_tools as env
 from fmtr.tools.constants import Constants
@@ -27,6 +29,8 @@ class Validator:
         raise NotImplementedError()
 
 
+api_key = env.get(Constants.FMTR_OPENAI_API_KEY_KEY, None)
+
 class Task(Generic[AgentDepsT, OutputDataT]):
     """
 
@@ -37,14 +41,14 @@ class Task(Generic[AgentDepsT, OutputDataT]):
     TypeDeps = str
     TypeOutput = str
 
-    PROVIDER = OpenAIProvider(api_key=env.get(Constants.FMTR_OPENAI_API_KEY_KEY))
+    PROVIDER = OpenAIProvider(api_key=api_key) if api_key else None
 
     API_HOST_FMTR = env.get(Constants.FMTR_AI_HOST_KEY, Constants.FMTR_AI_HOST_DEFAULT)
     API_URL_FMTR = f'https://{API_HOST_FMTR}/v1'
     PROVIDER_FMTR = OpenAIProvider(base_url=API_URL_FMTR)
 
     MODEL_ID = 'gpt-4o'
-    MODEL_ID_FMTR = 'qwen2.5-coder:14b'
+    MODEL_ID_FMTR = 'qwen2.5-coder:32b'
     SYSTEM_PROMPT_STATIC = None
     RESULT_RETRIES = 5
     VALIDATORS: List[Validator] = []
@@ -62,7 +66,7 @@ class Task(Generic[AgentDepsT, OutputDataT]):
             model=self.model,
             system_prompt=self.SYSTEM_PROMPT_STATIC or [],
             deps_type=self.TypeDeps,
-            output_type=self.TypeOutput,
+            output_type=self.tool_output,
             output_retries=self.RESULT_RETRIES,
             **kwargs
         )
@@ -71,6 +75,16 @@ class Task(Generic[AgentDepsT, OutputDataT]):
         self.agent.system_prompt(self.add_system_prompt)
         self.history = []
 
+    @property
+    def tool_output(self) -> OutputSpec[OutputDataT]:
+        """
+
+        Tool output specification (e.g. ToolOutput/NativeOutput etc.)
+
+        """
+        return ToolOutput(self.TypeOutput)
+
+
     @property
     def sync_runner(self):
         """
@@ -180,11 +194,15 @@ if __name__ == '__main__':
 
 
     class TaskTest(Task):
-        # PROVIDER = Task.PROVIDER_FMTR
-        # MODEL_ID = 'qwen2.5-coder:14b'
+        PROVIDER = Task.PROVIDER_FMTR
+        MODEL_ID = Task.MODEL_ID_FMTR
         TypeOutput = TestOutput
         SYSTEM_PROMPT_STATIC = 'Tell the user jokes.'
 
+        @property
+        def tool_output(self) -> OutputSpec[TestOutput]:
+            return NativeOutput(self.TypeOutput)
+
         def add_system_prompt(self, ctx: RunContext[TestDeps]) -> str:
             return f'The jokes must be in the {ctx.deps.lang} language.'
 
