@@ -27,7 +27,15 @@ def identity(x: Any) -> Any:
     return x
 
 
-class Empty:
+class Special:
+    """
+
+    Classes to differentiate special arguments from primitive arguments.
+
+    """
+
+
+class Empty(Special):
     """
 
     Class to denote an unspecified object (e.g. argument) when `None` cannot be used.
@@ -35,7 +43,7 @@ class Empty:
     """
 
 
-class Raise:
+class Raise(Special):
     """
 
     Class to denote when a function should raise instead of e.g. returning a default.
@@ -43,4 +51,21 @@ class Raise:
     """
 
 
+class Auto(Special):
+    """
+
+    Class to denote when an argument should be inferred.
+
+    """
+
+
+class Required(Special):
+    """
+
+    Class to denote when an argument is required.
+
+    """
+
+
+
 EMPTY = Empty()
